pub fn diff(
a: &HashMap<String, Value>,
b: &HashMap<String, Value>,
) -> DiffResultExpand description
Compute a structural diff between two SYNX objects (top-level keys).
Keys present only in b appear in added.
Keys present only in a appear in removed.
Keys present in both but with different values appear in changed.
Keys present in both with equal values appear in unchanged.